@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_calc as a convenience to use as a script
 from osgeo_utils.gdal_calc import *  # noqa
 from osgeo_utils.gdal_calc import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_calc')
+deprecation_warn("gdal_calc")
 sys.exit(main(sys.argv))
