@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_merge as a convenience to use as a script
 from osgeo_utils.gdal_merge import *  # noqa
 from osgeo_utils.gdal_merge import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_merge')
+deprecation_warn("gdal_merge")
 sys.exit(main(sys.argv))
