@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdalattachpct as a convenience to use as a script
 from osgeo_utils.gdalattachpct import *  # noqa
 from osgeo_utils.gdalattachpct import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdalattachpct')
+deprecation_warn("gdalattachpct")
 sys.exit(main(sys.argv))
