@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdalcompare as a convenience to use as a script
 from osgeo_utils.gdalcompare import *  # noqa
 from osgeo_utils.gdalcompare import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdalcompare')
+deprecation_warn("gdalcompare")
 sys.exit(main(sys.argv))
