@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdalmove as a convenience to use as a script
 from osgeo_utils.gdalmove import *  # noqa
 from osgeo_utils.gdalmove import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdalmove')
+deprecation_warn("gdalmove")
 sys.exit(main(sys.argv))
