@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.ogrmerge as a convenience to use as a script
 from osgeo_utils.ogrmerge import *  # noqa
 from osgeo_utils.ogrmerge import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('ogrmerge')
+deprecation_warn("ogrmerge")
 sys.exit(main(sys.argv))
