@@ -1,6 +1,6 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 ###############################################################################
-# $Id: load2odbc.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 # Project:  OGR Python samples
 # Purpose:  Load ODBC table to an ODBC datastore.  Uses direct SQL
@@ -38,12 +38,12 @@ from osgeo import ogr
 
 
 def Usage():
-    print('Usage: load2odbc.py [-where attr_filter] infile odbc_dsn layer')
-    print('')
-    return 1
+    print("Usage: load2odbc.py [-where attr_filter] infile odbc_dsn layer")
+    print("")
+    return 2
 
 
-def main(argv):
+def main(argv=sys.argv):
     extents_flag = 1
     infile = None
     odbc_dsn = None
@@ -52,7 +52,7 @@ def main(argv):
 
     i = 1
     while i < len(argv):
-        if argv[i] == '-where':
+        if argv[i] == "-where":
             i = i + 1
             attr_filter = argv[i]
         elif infile is None:
@@ -77,7 +77,7 @@ def main(argv):
     in_layer = in_ds.GetLayerByName(layername)
 
     if in_layer is None:
-        print('Did not find layer: ', layername)
+        print("Did not find layer: ", layername)
         return 1
 
     if attr_filter is not None:
@@ -86,55 +86,55 @@ def main(argv):
     #############################################################################
     # Connect to ODBC DSN.
 
-    if odbc_dsn == 'stdout':
+    if odbc_dsn == "stdout":
         out_ds = None
     else:
-        if len(odbc_dsn) < 6 or odbc_dsn[:5] != 'ODBC:':
-            odbc_dsn = 'ODBC:' + odbc_dsn
+        if len(odbc_dsn) < 6 or odbc_dsn[:5] != "ODBC:":
+            odbc_dsn = "ODBC:" + odbc_dsn
 
         out_ds = ogr.Open(odbc_dsn)
 
         if out_ds is None:
-            print('Unable to connect to ' + odbc_dsn)
+            print("Unable to connect to " + odbc_dsn)
             return 1
 
     #############################################################################
     # Fetch layer definition, and defined output table on the same basis.
 
     try:
-        cmd = 'drop table ' + layername
+        cmd = "drop table " + layername
         if out_ds is None:
             print(cmd)
         else:
             out_ds.ExecuteSQL(cmd)
-    except:
+    except Exception:
         pass
 
     defn = in_layer.GetLayerDefn()
 
-    cmd = 'CREATE TABLE ' + layername + '( OGC_FID INTEGER, WKT_GEOMETRY MEMO'
+    cmd = "CREATE TABLE " + layername + "( OGC_FID INTEGER, WKT_GEOMETRY MEMO"
 
     if extents_flag:
-        cmd = cmd + ', XMIN NUMBER, YMIN NUMBER, XMAX NUMBER, YMAX NUMBER'
+        cmd = cmd + ", XMIN NUMBER, YMIN NUMBER, XMAX NUMBER, YMAX NUMBER"
 
     for iField in range(defn.GetFieldCount()):
         fielddef = defn.GetFieldDefn(iField)
-        cmd = cmd + ', ' + fielddef.GetName()
+        cmd = cmd + ", " + fielddef.GetName()
         if fielddef.GetType() == ogr.OFTInteger:
-            cmd = cmd + ' INTEGER'
+            cmd = cmd + " INTEGER"
         elif fielddef.GetType() == ogr.OFTString:
-            cmd = cmd + ' TEXT'
+            cmd = cmd + " TEXT"
         elif fielddef.GetType() == ogr.OFTReal:
-            cmd = cmd + ' NUMBER'
+            cmd = cmd + " NUMBER"
         else:
-            cmd = cmd + ' TEXT'
+            cmd = cmd + " TEXT"
 
-    cmd = cmd + ')'
+    cmd = cmd + ")"
 
     if out_ds is None:
         print(cmd)
     else:
-        print('ExecuteSQL: ', cmd)
+        print("ExecuteSQL: ", cmd)
         result = out_ds.ExecuteSQL(cmd)
         if result is not None:
             out_ds.ReleaseResultSet(result)
@@ -146,39 +146,39 @@ def main(argv):
     in_layer.ResetReading()
     feat = in_layer.GetNextFeature()
     while feat is not None:
-        cmd_start = 'INSERT INTO ' + layername + ' ( OGC_FID '
-        cmd_end = ') VALUES (%d' % feat.GetFID()
+        cmd_start = "INSERT INTO " + layername + " ( OGC_FID "
+        cmd_end = ") VALUES (%d" % feat.GetFID()
 
         geom = feat.GetGeometryRef()
         if geom is not None:
-            cmd_start = cmd_start + ', WKT_GEOMETRY'
+            cmd_start = cmd_start + ", WKT_GEOMETRY"
             cmd_end = cmd_end + ", '" + geom.ExportToWkt() + "'"
 
         if extents_flag and geom is not None:
             extent = geom.GetEnvelope()
-            cmd_start = cmd_start + ', XMIN, XMAX, YMIN, YMAX'
-            cmd_end = cmd_end + (', %.7f, %.7f, %.7f, %.7f' % extent)
+            cmd_start = cmd_start + ", XMIN, XMAX, YMIN, YMAX"
+            cmd_end = cmd_end + (", %.7f, %.7f, %.7f, %.7f" % extent)
 
         for iField in range(defn.GetFieldCount()):
             fielddef = defn.GetFieldDefn(iField)
             if feat.IsFieldSet(iField) != 0:
-                cmd_start = cmd_start + ', ' + fielddef.GetName()
+                cmd_start = cmd_start + ", " + fielddef.GetName()
 
             if fielddef.GetType() == ogr.OFTInteger:
-                cmd_end = cmd_end + ', ' + feat.GetFieldAsString(iField)
+                cmd_end = cmd_end + ", " + feat.GetFieldAsString(iField)
             elif fielddef.GetType() == ogr.OFTString:
                 cmd_end = cmd_end + ", '" + feat.GetFieldAsString(iField) + "'"
             elif fielddef.GetType() == ogr.OFTReal:
-                cmd_end = cmd_end + ', ' + feat.GetFieldAsString(iField)
+                cmd_end = cmd_end + ", " + feat.GetFieldAsString(iField)
             else:
                 cmd_end = cmd_end + ", '" + feat.GetFieldAsString(iField) + "'"
 
-        cmd = cmd_start + cmd_end + ')'
+        cmd = cmd_start + cmd_end + ")"
 
         if out_ds is None:
             print(cmd)
         else:
-            print('ExecuteSQL: ', cmd)
+            print("ExecuteSQL: ", cmd)
             out_ds.ExecuteSQL(cmd)
 
         feat.Destroy()
@@ -194,5 +194,5 @@ def main(argv):
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
