@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 # -*- coding: utf-8 -*-
 ###############################################################################
 # $Id$
@@ -37,16 +37,24 @@ from osgeo import gdal
 
 
 def needsVSICurl(filename):
-    return filename.startswith('http://') or filename.startswith('https://') or filename.startswith('ftp://')
+    return (
+        filename.startswith("http://")
+        or filename.startswith("https://")
+        or filename.startswith("ftp://")
+    )
 
 
 def iszip(filename):
-    return filename.endswith('.zip') or filename.endswith('.ZIP')
+    return filename.endswith(".zip") or filename.endswith(".ZIP")
 
 
 def istgz(filename):
-    return filename.endswith('.tgz') or filename.endswith('.TGZ') or \
-        filename.endswith('.tar.gz') or filename.endswith('.TAR.GZ')
+    return (
+        filename.endswith(".tgz")
+        or filename.endswith(".TGZ")
+        or filename.endswith(".tar.gz")
+        or filename.endswith(".TAR.GZ")
+    )
 
 
 def display_file(fout, dirname, prefix, filename, longformat, check_open=False):
@@ -54,18 +62,26 @@ def display_file(fout, dirname, prefix, filename, longformat, check_open=False):
     statBuf = None
     filename_displayed = prefix + filename
 
-    if dirname.endswith('/'):
+    if dirname.endswith("/"):
         dirname_with_slash = dirname
     else:
-        dirname_with_slash = dirname + '/'
+        dirname_with_slash = dirname + "/"
 
-    version_num = int(gdal.VersionInfo('VERSION_NUM'))
+    version_num = int(gdal.VersionInfo("VERSION_NUM"))
     if longformat:
         if version_num >= 1900:
-            statBuf = gdal.VSIStatL(dirname_with_slash + filename, gdal.VSI_STAT_EXISTS_FLAG | gdal.VSI_STAT_NATURE_FLAG | gdal.VSI_STAT_SIZE_FLAG)
+            statBuf = gdal.VSIStatL(
+                dirname_with_slash + filename,
+                gdal.VSI_STAT_EXISTS_FLAG
+                | gdal.VSI_STAT_NATURE_FLAG
+                | gdal.VSI_STAT_SIZE_FLAG,
+            )
     else:
         if version_num >= 1900:
-            statBuf = gdal.VSIStatL(dirname_with_slash + filename, gdal.VSI_STAT_EXISTS_FLAG | gdal.VSI_STAT_NATURE_FLAG)
+            statBuf = gdal.VSIStatL(
+                dirname_with_slash + filename,
+                gdal.VSI_STAT_EXISTS_FLAG | gdal.VSI_STAT_NATURE_FLAG,
+            )
 
     if statBuf is None and check_open:
         if version_num >= 1900:
@@ -73,15 +89,20 @@ def display_file(fout, dirname, prefix, filename, longformat, check_open=False):
         else:
             f = gdal.VSIFOpenL(dirname_with_slash + filename, "rb")
         if f is None:
-            sys.stderr.write('Cannot open %s\n' % (dirname_with_slash + filename))
+            sys.stderr.write("Cannot open %s\n" % (dirname_with_slash + filename))
             return
         gdal.VSIFCloseL(f)
 
-    if statBuf is not None and statBuf.IsDirectory() and not filename_displayed.endswith('/'):
+    if (
+        statBuf is not None
+        and statBuf.IsDirectory()
+        and not filename_displayed.endswith("/")
+    ):
         filename_displayed = filename_displayed + "/"
 
     if longformat and statBuf is not None:
         import time
+
         bdt = time.gmtime(statBuf.mtime)
         if stat.S_IMODE(statBuf.mode) != 0:
             permissions = stat.filemode(statBuf.mode)
@@ -89,30 +110,48 @@ def display_file(fout, dirname, prefix, filename, longformat, check_open=False):
             permissions = "dr-xr-xr-x"
         else:
             permissions = "-r--r--r--"
-        line = "%s  1 unknown unknown %12d %04d-%02d-%02d %02d:%02d %s\n" % \
-            (permissions, statBuf.size, bdt.tm_year, bdt.tm_mon, bdt.tm_mday, bdt.tm_hour, bdt.tm_min, filename_displayed)
+        line = "%s  1 unknown unknown %12d %04d-%02d-%02d %02d:%02d %s\n" % (
+            permissions,
+            statBuf.size,
+            bdt.tm_year,
+            bdt.tm_mon,
+            bdt.tm_mday,
+            bdt.tm_hour,
+            bdt.tm_min,
+            filename_displayed,
+        )
     else:
         line = filename_displayed + "\n"
 
     fout.write(line)
 
 
-def readDir(fout, dirname, prefix, longformat, recurse, depth, recurseInZip, recurseInTGZ, first=False):
+def readDir(
+    fout,
+    dirname,
+    prefix,
+    longformat,
+    recurse,
+    depth,
+    recurseInZip,
+    recurseInTGZ,
+    first=False,
+):
 
     if depth <= 0:
         return
 
     if needsVSICurl(dirname):
-        dirname = '/vsicurl/' + dirname
-        prefix = '/vsicurl/' + prefix
+        dirname = "/vsicurl/" + dirname
+        prefix = "/vsicurl/" + prefix
 
-    if recurseInZip and iszip(dirname) and not dirname.startswith('/vsizip'):
-        dirname = '/vsizip/' + dirname
-        prefix = '/vsizip/' + prefix
+    if recurseInZip and iszip(dirname) and not dirname.startswith("/vsizip"):
+        dirname = "/vsizip/" + dirname
+        prefix = "/vsizip/" + prefix
 
-    if recurseInTGZ and istgz(dirname) and not dirname.startswith('/vsitar'):
-        dirname = '/vsitar/' + dirname
-        prefix = '/vsitar/' + prefix
+    if recurseInTGZ and istgz(dirname) and not dirname.startswith("/vsitar"):
+        dirname = "/vsitar/" + dirname
+        prefix = "/vsitar/" + prefix
 
     lst = gdal.ReadDir(dirname)
     if lst is None:
@@ -120,41 +159,53 @@ def readDir(fout, dirname, prefix, longformat, recurse, depth, recurseInZip, rec
             original_dirname = dirname
             (dirname, filename) = os.path.split(dirname)
             if gdal.ReadDir(dirname) is None:
-                sys.stderr.write('Cannot open %s\n' % original_dirname)
+                sys.stderr.write("Cannot open %s\n" % original_dirname)
                 return
-            if dirname == '':
-                dirname = '.'
-                prefix = ''
+            if dirname == "":
+                dirname = "."
+                prefix = ""
             else:
-                prefix = dirname + '/'
+                prefix = dirname + "/"
             display_file(fout, dirname, prefix, filename, longformat, True)
     else:
         for filename in lst:
-            if filename == '.' or filename == '..':
+            if filename == "." or filename == "..":
                 continue
 
             display_file(fout, dirname, prefix, filename, longformat)
 
             if recurse:
                 new_prefix = prefix + filename
-                if not new_prefix.endswith('/'):
-                    new_prefix += '/'
-                readDir(fout, dirname + '/' + filename, new_prefix,
-                        longformat, recurse, depth - 1, recurseInZip, recurseInTGZ)
+                if not new_prefix.endswith("/"):
+                    new_prefix += "/"
+                readDir(
+                    fout,
+                    dirname + "/" + filename,
+                    new_prefix,
+                    longformat,
+                    recurse,
+                    depth - 1,
+                    recurseInZip,
+                    recurseInTGZ,
+                )
 
 
 def Usage():
-    print('Usage: gdal_ls [-l] [-r] [-depth d] [-Rzip] [-Rtgz] name_of_virtual_directory')
-    print('')
-    print('Display the list of files in a virtual directory, like /vsicurl or /vsizip')
-    print('')
-    print('Options :')
-    print(' -l : use a long listing format (same as ls -l)')
-    print(' -r : list subdirectories recursively')
-    print(' -depth d : recurse until depth d')
-    print(' -Rzip : list content of .zip archives')
-    print(' -Rtgz : list content of .tar.gz/.tgz archives (potentially slow on /vsicurl/)')
-    return -1
+    print(
+        "Usage: gdal_ls [-l] [-r] [-depth d] [-Rzip] [-Rtgz] name_of_virtual_directory"
+    )
+    print("")
+    print("Display the list of files in a virtual directory, like /vsicurl or /vsizip")
+    print("")
+    print("Options :")
+    print(" -l : use a long listing format (same as ls -l)")
+    print(" -r : list subdirectories recursively")
+    print(" -depth d : recurse until depth d")
+    print(" -Rzip : list content of .zip archives")
+    print(
+        " -Rtgz : list content of .tar.gz/.tgz archives (potentially slow on /vsicurl/)"
+    )
+    return 2
 
 
 def gdal_ls(argv, fout=sys.stdout):
@@ -173,29 +224,29 @@ def gdal_ls(argv, fout=sys.stdout):
     i = 1
     argc = len(argv)
     while i < argc:
-        if argv[i] == '-l':
+        if argv[i] == "-l":
             longformat = True
-        elif argv[i] == '-lr':
+        elif argv[i] == "-lr":
             longformat = True
             recurse = True
-        elif argv[i] == '-R' or argv[i] == '-r':
+        elif argv[i] == "-R" or argv[i] == "-r":
             recurse = True
-        elif argv[i] == '-Rzip':
+        elif argv[i] == "-Rzip":
             recurseInZip = True
-        elif argv[i] == '-Rtgz':
+        elif argv[i] == "-Rtgz":
             recurseInTGZ = True
-        elif argv[i] == '-noprefix':
+        elif argv[i] == "-noprefix":
             display_prefix = False
-        elif argv[i] == '-depth' and i < len(argv) - 1:
+        elif argv[i] == "-depth" and i < len(argv) - 1:
             depth = int(argv[i + 1])
             i = i + 1
-        elif argv[i][0] == '-':
-            sys.stderr.write('Unrecognized option : %s\n' % argv[i])
+        elif argv[i][0] == "-":
+            sys.stderr.write("Unrecognized option : %s\n" % argv[i])
             return Usage()
         elif dirname is None:
             dirname = argv[i]
         else:
-            sys.stderr.write('Unexpected option : %s\n' % argv[i])
+            sys.stderr.write("Unexpected option : %s\n" % argv[i])
             return Usage()
 
         i = i + 1
@@ -204,11 +255,11 @@ def gdal_ls(argv, fout=sys.stdout):
         return Usage()
 
     # Remove trailing
-    if dirname[-1] == '/':
-        dirname = dirname[0:len(dirname) - 1]
+    if dirname[-1] == "/":
+        dirname = dirname[0 : len(dirname) - 1]
 
     if needsVSICurl(dirname):
-        dirname = '/vsicurl/' + dirname
+        dirname = "/vsicurl/" + dirname
 
     # if iszip(dirname) and not dirname.startswith('/vsizip'):
     #    dirname = '/vsizip/' + dirname
@@ -216,10 +267,20 @@ def gdal_ls(argv, fout=sys.stdout):
     # if istgz(dirname) and not dirname.startswith('/vsitar'):
     #    dirname = '/vsitar/' + dirname
 
-    prefix = ''
+    prefix = ""
     if display_prefix:
-        prefix = dirname + '/'
-    readDir(fout, dirname, prefix, longformat, recurse, depth, recurseInZip, recurseInTGZ, True)
+        prefix = dirname + "/"
+    readDir(
+        fout,
+        dirname,
+        prefix,
+        longformat,
+        recurse,
+        depth,
+        recurseInZip,
+        recurseInTGZ,
+        True,
+    )
     return 0
 
 
@@ -227,10 +288,10 @@ def main(argv=sys.argv):
     return gdal_ls(argv)
 
 
-if __name__ == '__main__':
-    version_num = int(gdal.VersionInfo('VERSION_NUM'))
+if __name__ == "__main__":
+    version_num = int(gdal.VersionInfo("VERSION_NUM"))
     if version_num < 1800:
-        sys.stderr.write('ERROR: Python bindings of GDAL 1.8.0 or later required\n')
+        sys.stderr.write("ERROR: Python bindings of GDAL 1.8.0 or later required\n")
         sys.exit(1)
 
     sys.exit(main(sys.argv))
