@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 ###############################################################################
 # $Id$
 #
@@ -29,15 +29,18 @@
 ###############################################################################
 
 import sys
+
 from osgeo import gdal
 
 gdal.TermProgress = gdal.TermProgress_nocb
 
 
 def Usage():
-    print('Usage: gdalfilter.py [-n] [-size n] [-coefs ...] [-f format] [-co NAME=VALUE]\n'
-          '                     in_file out_file')
-    return 1
+    print(
+        "Usage: gdalfilter.py [-n] [-size n] [-coefs ...] [-f format] [-co NAME=VALUE]\n"
+        "                     in_file out_file"
+    )
+    return 2
 
 
 def main(argv=sys.argv):
@@ -58,29 +61,31 @@ def main(argv=sys.argv):
     while i < len(argv):
         arg = argv[i]
 
-        if arg == '-size':
+        if arg == "-size":
             size = int(argv[i + 1])
             i = i + 1
 
-        elif arg == '-n':
+        elif arg == "-n":
             normalized = 1
 
-        elif arg == '-f':
+        elif arg == "-f":
             out_format = int(argv[i + 1])
             i = i + 1
 
-        elif arg == '-co':
+        elif arg == "-co":
             create_options.append(argv[i + 1])
             i = i + 1
 
-        elif arg == '-coefs':
+        elif arg == "-coefs":
             coefs = []
             for iCoef in range(size * size):
                 try:
                     coefs.append(float(argv[iCoef + i + 1]))
-                except:
-                    print("Didn't find enough valid kernel coefficients, need ",
-                          size * size)
+                except Exception:
+                    print(
+                        "Didn't find enough valid kernel coefficients, need ",
+                        size * size,
+                    )
                     return 1
             i = i + size * size
 
@@ -91,17 +96,17 @@ def main(argv=sys.argv):
             dstfile = argv[i]
 
         else:
-            Usage()
+            return Usage()
 
         i = i + 1
 
     if dstfile is None:
-        Usage()
+        return Usage()
 
-    if out_format is None and dstfile[-4:].lower() == '.vrt':
-        out_format = 'VRT'
+    if out_format is None and dstfile[-4:].lower() == ".vrt":
+        out_format = "VRT"
     else:
-        out_format = 'GTiff'
+        out_format = "GTiff"
 
     # =============================================================================
     #   Open input file.
@@ -114,8 +119,8 @@ def main(argv=sys.argv):
     #   the input file.
     # =============================================================================
 
-    vrt_driver = gdal.GetDriverByName('VRT')
-    vrt_ds = vrt_driver.CreateCopy('', src_ds)
+    vrt_driver = gdal.GetDriverByName("VRT")
+    vrt_ds = vrt_driver.CreateCopy("", src_ds)
 
     # =============================================================================
     #   Prepare coefficient list.
@@ -127,23 +132,27 @@ def main(argv=sys.argv):
         for i in range(coef_list_size):
             coefs.append(1.0 / coef_list_size)
 
-    coefs_string = ''
+    coefs_string = ""
     for i in range(coef_list_size):
-        coefs_string = coefs_string + ('%.8g ' % coefs[i])
+        coefs_string = coefs_string + ("%.8g " % coefs[i])
 
     # =============================================================================
     #   Prepare template for XML description of the filtered source.
     # =============================================================================
 
-    filt_template = \
-        '''<KernelFilteredSource>
+    filt_template = """<KernelFilteredSource>
       <SourceFilename>%s</SourceFilename>
       <SourceBand>%%d</SourceBand>
       <Kernel normalized="%d">
         <Size>%d</Size>
         <Coefs>%s</Coefs>
       </Kernel>
-    </KernelFilteredSource>''' % (srcfile, normalized, size, coefs_string)
+    </KernelFilteredSource>""" % (
+        srcfile,
+        normalized,
+        size,
+        coefs_string,
+    )
 
     # =============================================================================
     # Go through all the bands replacing the SimpleSource with a filtered source.
@@ -154,24 +163,25 @@ def main(argv=sys.argv):
 
         src_xml = filt_template % (iBand + 1)
 
-        band.SetMetadata({'source_0': src_xml}, 'vrt_sources')
+        band.SetMetadata({"source_0": src_xml}, "vrt_sources")
 
     # =============================================================================
     # copy the results to a new file.
     # =============================================================================
 
-    if out_format == 'VRT':
+    if out_format == "VRT":
         vrt_ds.SetDescription(dstfile)
         vrt_ds = None
         return 0
 
     out_driver = gdal.GetDriverByName(out_format)
     if out_driver is None:
-        print('Output driver %s does not appear to exist.' % out_format)
+        print("Output driver %s does not appear to exist." % out_format)
         return 0
 
-    out_ds = out_driver.CreateCopy(dstfile, vrt_ds, options=create_options,
-                                   callback=gdal.TermProgress)
+    out_ds = out_driver.CreateCopy(
+        dstfile, vrt_ds, options=create_options, callback=gdal.TermProgress
+    )
     if out_ds is None:
         return 1
     else:
@@ -179,5 +189,5 @@ def main(argv=sys.argv):
         return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
